@@ -332,6 +332,7 @@ class CConfigurationExport {
 			$templates = $this->gatherItems($templates);
 			$templates = $this->gatherDiscoveryRules($templates);
 			$templates = $this->gatherHttpTests($templates);
+			$templates = $this->removeHttpTestItems($templates);
 		}
 
 		$this->data['templates'] = $templates;
@@ -376,6 +377,7 @@ class CConfigurationExport {
 			$hosts = $this->gatherItems($hosts);
 			$hosts = $this->gatherDiscoveryRules($hosts);
 			$hosts = $this->gatherHttpTests($hosts);
+			$hosts = $this->removeHttpTestItems($hosts);
 		}
 
 		$this->data['hosts'] = $hosts;
@@ -497,11 +499,7 @@ class CConfigurationExport {
 		}
 		unset($item);
 
-		foreach ($items as $itemid => $item) {
-			if ($item['type'] == ITEM_TYPE_HTTPTEST) {
-				unset($items[$itemid]);
-			}
-		}
+		// Web items will be removed from result after all items and discovery rules are gathered and processed.
 
 		$items = $this->prepareItems($items);
 
@@ -600,14 +598,14 @@ class CConfigurationExport {
 
 		$discovery_rules = $this->prepareDiscoveryRules($discovery_rules);
 
+		// Discovery rules may use web items as master items.
 		foreach ($discovery_rules as $discovery_rule) {
 			if ($discovery_rule['type'] == ITEM_TYPE_DEPENDENT) {
-				if (!array_key_exists($discovery_rule['master_itemid'], $itemids)) {
-					// Do not export dependent discovery rule with master item from template.
-					continue;
-				}
+				$master_itemid = $discovery_rule['master_itemid'];
 
-				$discovery_rule['master_item'] = ['key_' => $itemids[$discovery_rule['master_itemid']]];
+				if (array_key_exists($master_itemid, $itemids)) {
+					$discovery_rule['master_item'] = ['key_' => $itemids[$master_itemid]];
+				}
 			}
 
 			foreach ($discovery_rule['itemPrototypes'] as $itemid => $item_prototype) {
@@ -1691,4 +1689,26 @@ class CConfigurationExport {
 
 		return $ids;
 	}
+
+	/**
+	 * Remove web items.
+	 *
+	 * @param array $hosts  Array of hosts or templates to remove the web items from.
+	 *
+	 * @return array
+	 */
+	protected function removeHttpTestItems(array $hosts) {
+		foreach ($hosts as &$host) {
+			if ($host['items']) {
+				foreach ($host['items'] as $idx => $item) {
+					if ($item['type'] == ITEM_TYPE_HTTPTEST) {
+						unset($host['items'][$idx]);
+					}
+				}
+			}
+		}
+		unset($host);
+
+		return $hosts;
+	}
 }
